<form class="sidebar-search-container" method="get" action="{{ pathto('search') }}">
  <input class="sidebar-search" placeholder={{ _("Search") }} name="q">
  <input type="hidden" name="check_keywords" value="yes">
  <input type="hidden" name="area" value="default">
</form>
